package org.processmining.glueminer.algorithms;

import java.util.Date;
import java.util.List;
import java.util.Random;

import org.deckfour.xes.model.XAttributeMap;
import org.deckfour.xes.model.XEvent;
import org.deckfour.xes.model.XLog;
import org.deckfour.xes.model.XTrace;
import org.deckfour.xes.model.impl.XAttributeLiteralImpl;
import org.deckfour.xes.model.impl.XAttributeMapImpl;
import org.deckfour.xes.model.impl.XAttributeTimestampImpl;
import org.deckfour.xes.model.impl.XEventImpl;
import org.deckfour.xes.model.impl.XLogImpl;
import org.deckfour.xes.model.impl.XTraceImpl;
import org.processmining.glueminer.models.GeneratedPetrinet;
import org.processmining.glueminer.parameters.LogGeneratorParameters;

public class LogGenerator {
	GeneratedPetrinet gnet;
	int wantedTraces;
	double prUncompleteness;
	double prSkipping;
	double prInserting;
	int maxTraceLength;
	
	public LogGenerator(GeneratedPetrinet gnet, LogGeneratorParameters parameters) {
		this.gnet = gnet;
		this.wantedTraces = parameters.wantedTraces;
		this.prUncompleteness = parameters.prUncompleteness;
		this.prSkipping = parameters.prSkipping;
		this.prInserting = parameters.prInserting;
		this.maxTraceLength = parameters.maxTraceLength;
	}
	
	public XLog generateXLog() {
		XAttributeMap logAttributeMap = new XAttributeMapImpl();
		XLog log = new XLogImpl(logAttributeMap);
		log.getAttributes().put("concept:name", new XAttributeLiteralImpl("concept:name", "testlog"));
		
		Long sumOfTimes = new Long(0);
		Random random = new Random();
		
		int i = 0;
		while (i < wantedTraces) {
			XAttributeMap traceAttributeMap = new XAttributeMapImpl();
			XTrace tr = new XTraceImpl(traceAttributeMap);
			tr.getAttributes().put("concept:name", new XAttributeLiteralImpl("concept:name", "tr"+i));

			List<String> traceActivities = gnet.getSingleTraceActivities(prUncompleteness, prSkipping, prInserting, maxTraceLength);
			
			//System.out.println(traceActivities);
			
			int j = 0;
			while (j < traceActivities.size()) {
				sumOfTimes += random.nextInt(3600);
				Date currentDate = new Date(sumOfTimes);
				
				String activity = traceActivities.get(j);
				
				XAttributeMap eventAttributeMap = new XAttributeMapImpl();
				XEvent eve = new XEventImpl(eventAttributeMap);
				
				eve.getAttributes().put("concept:name", new XAttributeLiteralImpl("concept:name", activity));
				eve.getAttributes().put("time:timestamp", new XAttributeTimestampImpl("time:timestamp", currentDate));
				
				tr.add(eve);
				
				j++;
			}
			
			log.add(tr);
			
			i++;
		}
		
		//System.out.println(log);
		
		return log;
	}
}
