package org.processmining.glueminer.plugins;

import java.util.ArrayList;
import java.util.List;

import org.deckfour.xes.model.XLog;
import org.processmining.contexts.uitopia.UIPluginContext;
import org.processmining.contexts.uitopia.annotations.UITopiaVariant;
import org.processmining.framework.plugin.annotations.Plugin;
import org.processmining.framework.plugin.annotations.PluginCategory;
import org.processmining.framework.plugin.annotations.PluginLevel;
import org.processmining.framework.plugin.annotations.PluginQuality;
import org.processmining.framework.plugin.annotations.PluginVariant;
import org.processmining.framework.util.ui.wizard.ListWizard;
import org.processmining.framework.util.ui.wizard.ProMWizardDisplay;
import org.processmining.framework.util.ui.wizard.ProMWizardStep;
import org.processmining.glueminer.algorithms.LogGenerator;
import org.processmining.glueminer.dialogs.LogGeneratorPluginWizardStep;
import org.processmining.glueminer.models.GeneratedPetrinet;
import org.processmining.glueminer.parameters.LogGeneratorParameters;

@Plugin(name = "Generate log from Petri Net", level = PluginLevel.NightlyBuild, parameterLabels = { "Generated Petri Net"}, returnLabels = { "Log" }, returnTypes = { XLog.class }, help = "No help", quality = PluginQuality.VeryGood, categories = {
		PluginCategory.Discovery })
public class LogGeneratorPlugin {
	@UITopiaVariant(affiliation = "PADS", author = "Alessandro Berti", email = "a.berti@pads.rwth-aachen.de")
	@PluginVariant(requiredParameterLabels = { 0 })
	public static XLog getLogFromGeneratedPetrinet(UIPluginContext context, GeneratedPetrinet gnet) {
		LogGeneratorParameters parameters;
		
		LogGeneratorPluginWizardStep wizardStep = new LogGeneratorPluginWizardStep(gnet.net);
		List<ProMWizardStep<LogGeneratorParameters>> wizStepList = new ArrayList<>();
		wizStepList.add(wizardStep);
		ListWizard<LogGeneratorParameters> listWizard = new ListWizard<>(wizStepList);
		
		parameters = ProMWizardDisplay.show(context, listWizard, new LogGeneratorParameters());
		
		XLog returnedLog = null;
		if (parameters != null) {
			LogGenerator logGenerator = new LogGenerator(gnet, parameters);
			returnedLog = logGenerator.generateXLog();
		}
		
		return returnedLog;
	}
}
